%global lua_incdir %{_includedir}/lua-%{lua_version}
%global lua_builddir obj-lua%{lua_version}

%global lua_51_version 5.1
%global lua_51_incdir %{_includedir}/lua-%{lua_51_version}
%global lua_51_libdir %{_libdir}/lua/%{lua_51_version}
%global lua_51_pkgdir %{_datadir}/lua/%{lua_51_version}
%global lua_51_builddir obj-lua%{lua_51_version}

%global luajit_version 2.1
%global luajit_incdir %{_includedir}/luajit-%{luajit_version}
%global luajit_libdir %{_libdir}/luajit/%{luajit_version}
%global luajit_builddir obj-luajit

%global real_version 1.44.2
%global extra_version 1

%global common_description %{expand:
This library makes libuv available to lua scripts. It was made for the luvit project but
should usable from nearly any lua project.

The library can be used by multiple threads at once. Each thread is assumed to load the
library from a different lua_State. Luv will create a unique uv_loop_t for each state.
You can't share uv handles between states/loops.

The best docs currently are the libuv docs themselves. Hopefully soon we'll have a copy
locally tailored for lua.}

Summary:        Bare libuv bindings for lua
Name:           lua-luv
Version:        %{real_version}.%{extra_version}
Release:        4%{?dist}
License:        ASL 2.0
Url:            https://github.com/luvit/luv
Source0:        %{url}/archive/%{real_version}-%{extra_version}/luv-%{version}.tar.gz

Patch3000:      lua-luv-disable-udp-test.patch

BuildRequires:  cmake gcc libuv-devel lua-devel compat-lua compat-lua-devel luajit-devel lua5.1-compat53

Requires:       lua(abi) = %{lua_version}

%description
%common_description

%package devel
Summary:        Development files for lua-luv
Requires:       lua-luv = %{version}-%{release}

%description devel
Files required for lua-luv development

%package -n lua5.1-luv
Summary:        Bare libuv bindings for lua 5.1
Requires:       lua(abi) = %{lua_51_version}

%description -n lua5.1-luv
%common_description

%package -n lua5.1-luv-devel
Summary:        Development files for lua5.1-luv
Requires:       lua5.1-luv = %{version}-%{release}

%description -n lua5.1-luv-devel
Files required for lua5.1-luv development

%package -n luajit%{luajit_version}-luv
Summary:        Bare libuv bindings for lua 5.1
Requires:       lua(abi) = %{lua_51_version}

%description -n luajit%{luajit_version}-luv
%common_description

%package -n luajit%{luajit_version}-luv-devel
Summary:        Development files for luajit%{luajit_version}-luv
Requires:       luajit%{luajit_version}-luv = %{version}-%{release}

%description -n luajit%{luajit_version}-luv-devel
%common_description

Files required for luajit%{luajit_version}-luv development

%prep
%autosetup -n luv-%{real_version}-%{extra_version} -p1

rm -rf deps
rm -f tests/test-dns.lua

%build
mkdir %{lua_builddir}
%global __cmake_builddir  %{lua_builddir}

%cmake \
    -DWITH_SHARED_LIBUV=ON \
    -DBUILD_MODULE=ON \
    -DBUILD_SHARED_LIBS=ON \
    -DWITH_LUA_ENGINE=Lua \
    -DLUA_BUILD_TYPE=System \
    -DINSTALL_LIB_DIR=%{_libdir} \
    -DLUA_INCLUDE_DIR=%{lua_incdir} \
    %{nil}

%cmake_build

mkdir %{lua_51_builddir}
%global __cmake_builddir %{lua_51_builddir}

%cmake \
    -DWITH_SHARED_LIBUV=ON \
    -DBUILD_MODULE=ON \
    -DBUILD_SHARED_LIBS=ON \
    -DWITH_LUA_ENGINE=Lua \
    -DLUA_BUILD_TYPE=System \
    -DINSTALL_LIB_DIR=%{_libdir} \
    -DLUA_COMPAT53_DIR=%{lua_51_incdir} \
    -DLUA_INCLUDE_DIR=%{lua_51_incdir} \
    -DLUA_LIBRARY=%{_libdir}/liblua-%{lua_51_version}.so \
    %{nil}

%cmake_build

mkdir %{luajit_builddir}
%global __cmake_builddir %{luajit_builddir}

%cmake \
    -DWITH_SHARED_LIBUV=ON \
    -DBUILD_MODULE=ON \
    -DBUILD_SHARED_LIBS=ON \
    -DWITH_LUA_ENGINE=LuaJit \
    -DLUA_BUILD_TYPE=System \
    -DINSTALL_LIB_DIR=%{_libdir} \
    -DLUA_COMPAT53_DIR=%{lua_51_incdir} \
    %{nil}

%cmake_build

%install
install -Dm 0755 -p %{lua_builddir}/luv.so %{buildroot}%{lua_libdir}/luv.so

install -d -m 0755 %{buildroot}%{lua_incdir}/luv
for f in lhandle.h lreq.h luv.h util.h; do
    install -m 0644 -p src/$f %{buildroot}%{lua_incdir}/luv/$f
done

install -Dm 0755 -p %{lua_51_builddir}/luv.so %{buildroot}%{lua_51_libdir}/luv.so

install -d -m 0755 %{buildroot}%{lua_51_incdir}/luv
for f in lhandle.h lreq.h luv.h util.h; do
    install -m 0644 -p src/$f %{buildroot}%{lua_51_incdir}/luv/$f
done

install -Dm 0755 -p %{luajit_builddir}/luv.so %{buildroot}%{luajit_libdir}/luv.so

install -d -m 0755 %{buildroot}%{luajit_incdir}/luv
for f in lhandle.h lreq.h luv.h util.h; do
    install -m 0644 -p src/$f %{buildroot}%{luajit_incdir}/luv/$f
done

%check
ln -sf %{lua_51_builddir}/luv.so luv.so
lua-5.1 tests/run.lua
rm luv.so
ln -sf %{lua_builddir}/luv.so luv.so
lua tests/run.lua
rm luv.so

ln -sf %{luajit_builddir}/luv.so luv.so
%ifarch aarch64
rm tests/test-work.lua
%endif
luajit tests/run.lua
rm luv.so

%files
%license LICENSE.txt
%doc README.md
%{lua_libdir}/luv.so

%files devel
%dir %{lua_incdir}
%dir %{lua_incdir}/luv/
%{lua_incdir}/luv/lhandle.h
%{lua_incdir}/luv/lreq.h
%{lua_incdir}/luv/luv.h
%{lua_incdir}/luv/util.h

%files -n lua5.1-luv
%license LICENSE.txt
%doc README.md
%{lua_51_libdir}/luv.so

%files -n lua5.1-luv-devel
%dir %{lua_51_incdir}
%dir %{lua_51_incdir}/luv/
%{lua_51_incdir}/luv/lhandle.h
%{lua_51_incdir}/luv/lreq.h
%{lua_51_incdir}/luv/luv.h
%{lua_51_incdir}/luv/util.h

%files -n luajit%{luajit_version}-luv
%license LICENSE.txt
%doc README.md
%{luajit_libdir}/luv.so

%files -n luajit%{luajit_version}-luv-devel
%dir %{luajit_incdir}
%dir %{luajit_incdir}/luv/
%{luajit_incdir}/luv/lhandle.h
%{luajit_incdir}/luv/lreq.h
%{luajit_incdir}/luv/luv.h
%{luajit_incdir}/luv/util.h

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.44.2.1-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.44.2.1-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.44.2.1-2
- Rebuilt for OpenCloudOS Stream 23

* Mon Jan 16 2023 Shuo Wang <abushwang@tencent.com> - 1.44.2.1-1
- initial build
